@@ -1,5 +1,5 @@
 /*
- *   $Id: includes.h,v 1.13 2005/10/18 19:17:29 lutchann Exp $
+ *   $Id: includes.h,v 1.14 2007/10/25 19:29:40 psavola Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -95,4 +95,8 @@
 # include <getopt.h>
 #endif
 
+#ifdef HAVE_IFADDRS_H
+# include <ifaddrs.h>
+#endif
+
 #endif /* INCLUDES_H */
