@@ -1,5 +1,5 @@
 /*
- *   $Id: util.c,v 1.8 2006/10/08 19:20:02 psavola Exp $
+ *   $Id: util.c,v 1.9 2008/01/24 10:03:17 psavola Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -63,3 +63,45 @@ check_rdnss_presence(struct AdvRDNSS *rdnss, struct in6_addr *addr)
 	}
 	return (rdnss != NULL);
 }
+
+/* Like read(), but retries in case of partial read */
+ssize_t
+readn(int fd, void *buf, size_t count)
+{
+	size_t n = 0;
+	while (count > 0) {
+		int r = read(fd, buf, count);
+		if (r < 0) {
+			if (errno == EINTR)
+				continue;
+			return r;
+		}
+		if (r == 0)
+			return n;
+		buf = (char *)buf + r;
+		count -= r;
+		n += r;
+	}
+	return n;
+}
+
+/* Like write(), but retries in case of partial write */
+ssize_t
+writen(int fd, const void *buf, size_t count)
+{
+	size_t n = 0;
+	while (count > 0) {
+		int r = write(fd, buf, count);
+		if (r < 0) {
+			if (errno == EINTR)
+				continue;
+			return r;
+		}
+		if (r == 0)
+			return n;
+		buf = (char *)buf + r;
+		count -= r;
+		n += r;
+	}
+	return n;
+}
